.. role:: hidden
    :class: hidden-section

Modelling
=========

.. automodule:: pyeeg.models
    :no-members:
    :no-inherited-members:

Classes
-------
.. currentmodule:: pyeeg.models

.. autosummary::
   :toctree: generated/
   :template: class.rst

   pyeeg.models.TRFEstimator
   
.. currentmodule:: pyeeg.cca

.. autosummary::
   :toctree: generated/
   :template: class.rst
   
   pyeeg.cca.CCA_Estimator

Functions
---------
.. currentmodule:: pyeeg.models

.. autosummary:: 
    :toctree: generated/
    :template: function.rst

    pyeeg.models._svd_regress
